It prints the results of AUC comparison for MRMC data.
summary_AUC_comparison_MRMC(StanS4class, significantLevel = 0.8, dig = 3)An S4 object of class stanfitExtended which is an inherited class from the S4 class stanfit.
This R object is a fitted model object
as a return value of the function fit_Bayesian_FROC().
It can be passed to DrawCurves(), ppp() and ... etc
This is a number between 0 and 1. The results are shown if posterior probabilities are greater than this quantity.