Trace plot
trace_Plot(
StanS4class,
param_name = name_of_param_whose_Rhat_is_maximal(StanS4class),
chains = 1:length(StanS4class@stan_args),
type = 2,
new.imaging.device = TRUE,
omit_initial_iter = 13
)An S4 object of class stanfitExtended which is an inherited class from the S4 class stanfit.
This R object is a fitted model object
as a return value of the function fit_Bayesian_FROC().
To be passed to DrawCurves(), ppp() and ... etc
character, indicating param name.
An positive integer, indicating the number of chains in MCMC
An integer, for the color of background and etc.
Logical: TRUE of FALSE. If TRUE (default), then open a new device to draw curve.
Using this we can draw curves in same plain by new.imaging.device=FALSE.
A positive integer, except which from the first iteration, trace plot is drawn